/****************************************************************************
**
** Copyright (C) 2017 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the examples of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:BSD$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** BSD License Usage
** Alternatively, you may use this file under the terms of the BSD license
** as follows:
**
** "Redistribution and use in source and binary forms, with or without
** modification, are permitted provided that the following conditions are
** met:
**   * Redistributions of source code must retain the above copyright
**     notice, this list of conditions and the following disclaimer.
**   * Redistributions in binary form must reproduce the above copyright
**     notice, this list of conditions and the following disclaimer in
**     the documentation and/or other materials provided with the
**     distribution.
**   * Neither the name of The Qt Company Ltd nor the names of its
**     contributors may be used to endorse or promote products derived
**     from this software without specific prior written permission.
**
**
** THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
** "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
** LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
** A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
** OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
** SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
** LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
** DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
** THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
** (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
** OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE."
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef SCRIPTBREAKPOINTMANAGER_H
#define SCRIPTBREAKPOINTMANAGER_H

#include <QtCore/qlist.h>
#include <QtCore/qstring.h>
#include <QtScript/qscriptvalue.h>

class ScriptBreakpointInfo
{
public:
    enum Type {
        File,
        FunctionName,
        Function,
        Invalid
    };

    Type type;
    QString functionName;
    QString fileName;
    int lineNumber;
    QScriptValue function;
    bool enabled;
    QString condition;
    int ignoreCount;
    bool singleShot;

    ScriptBreakpointInfo(const QString &fileName, int lineNumber)
        : type(File), fileName(fileName), lineNumber(lineNumber),
          enabled(true), ignoreCount(0), singleShot(false)
        { }
    ScriptBreakpointInfo(const QString &functionName, const QString &fileName = QString())
        : type(FunctionName), functionName(functionName), fileName(fileName),
          enabled(true), ignoreCount(0), singleShot(false)
        { }
    ScriptBreakpointInfo(const QScriptValue &function)
        : type(Function), function(function),
          enabled(true), ignoreCount(0), singleShot(false)
        { }
    ScriptBreakpointInfo()
        : type(Invalid)
        { }
};

class ScriptBreakpointManager
{
public:
    ScriptBreakpointManager();
    ~ScriptBreakpointManager();

    bool hasBreakpoints() const;

    int setBreakpoint(const QString &fileName, int lineNumber);
    int setBreakpoint(const QString &functionName, const QString &fileName = QString());
    int setBreakpoint(const QScriptValue &function);

    void removeBreakpoint(int id);

    int findBreakpoint(const QString &fileName, int lineNumber) const;
    int findBreakpoint(const QString &functionName, const QString &fileName = QString()) const;
    int findBreakpoint(const QScriptValue &function) const;

    bool isBreakpointEnabled(int id) const;
    void setBreakpointEnabled(int id, bool enabled);

    QString breakpointCondition(int id) const;
    void setBreakpointCondition(int id, const QString &expression);

    int breakpointIgnoreCount(int id) const;
    void setBreakpointIgnoreCount(int id, int ignoreCount);

    bool isBreakpointSingleShot(int id) const;
    void setBreakpointSingleShot(int id, bool singleShot);

private:
    QList<ScriptBreakpointInfo> breakpoints;

    Q_DISABLE_COPY(ScriptBreakpointManager)
};

#endif // SCRIPTBREAKPOINTMANAGER_H
